
Changelog
=========

0.1.1 (2020-08-15)
------------------

* Initial PyPI release
* Various tox, badge, and metadata fixes
* Removed unused temperature unit conversion functions
* Updated Python version requirements
* Minor documentation clean up

0.1.0 (2020-08-08)
------------------

* Added basic functionality

  * Reading/writing of Watlow parameters
  * Request message generation
  * Calculation of check bytes
  * Response message parsing
